@@ -13,7 +13,7 @@ Usage example::
 from dodfminer.cli import CLI
 from dodfminer.downloader.core import Downloader
 from dodfminer.extract.pure.core import ContentExtractor
-from dodfminer.extract.polished.helper import extract_multiple_acts, xml_multiple, extract_segments
+from dodfminer.extract.polished.helper import extract_multiple_acts, xml_multiple
 
 
 class Miner(object):
@@ -42,10 +42,6 @@ class Miner(object):
 
     def extract_content(self):
         """Extract Content from PDFs."""
-
-        if self.args.segmentation is not False:
-            self.args.segmentation = True
-
         if self.args.single_file is None:
             if self.args.type_of_extr is not None:
                 if self.args.type_of_extr == 'pure-text':
@@ -55,10 +51,8 @@ class Miner(object):
                                                      titles_with_boxes=True)
                 elif self.args.type_of_extr == 'blocks':
                     ContentExtractor.extract_to_json(folder=self.args.input_folder)
-                elif self.args.type_of_extr == 'segments':
-                    extract_segments(path=self.args.input_folder)
             elif self.args.act != 'all':
-                extract_multiple_acts(self.args.input_folder, self.args.act, self.args.backend, segmentation=self.args.segmentation)
+                extract_multiple_acts(self.args.input_folder, self.args.act, self.args.backend)
             elif self.args.xml != False:
                 xml_multiple(self.args.input_folder, self.args.backend)
             else:
@@ -73,10 +67,8 @@ class Miner(object):
                                                        single=True)
                 elif self.args.type_of_extr == 'blocks':
                     ContentExtractor.extract_text(self.args.single_file, single=True, block=True)
-                elif self.args.type_of_extr == 'segments':
-                    extract_segments(path=self.args.single_file)
             elif self.args.act != 'all':
-                extract_multiple_acts(self.args.single_file, self.args.act, self.args.backend, segmentation=self.args.segmentation)
+                extract_multiple_acts(self.args.single_file, self.args.act, self.args.backend)
             elif self.args.xml != False:
                 xml_multiple(self.args.single_file, self.args.backend)
             else:
